@@ -31,9 +31,9 @@ answer_to_connection (void *cls, struct MHD_Connection *connection,
         "<html><body>An internal server error has occured!\
                               </body></html>";
       response =
-	MHD_create_response_from_data (strlen (errorstr), 
-				       (void *) errorstr, 
-				       MHD_NO, MHD_NO);
+	MHD_create_response_from_buffer (strlen (errorstr), 
+					 (void *) errorstr, 
+					 MHD_RESPMEM_PERSISTENT);
       if (response)
         {
           ret =
@@ -47,7 +47,7 @@ answer_to_connection (void *cls, struct MHD_Connection *connection,
         return MHD_NO;
     }
   response =
-    MHD_create_response_from_fd (fd, sbuf.st_size);
+    MHD_create_response_from_fd_at_offset (fd, sbuf.st_size, 0);
   MHD_add_response_header (response, "Content-Type", MIMETYPE);
   ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
   MHD_destroy_response (response);
