@@ -270,13 +270,9 @@ static ssize_t
 file_reader (void *cls, uint64_t pos, char *buf, size_t max)
 {
   struct MHD_Response *response = cls;
-  int ret;
 
-  pthread_mutex_lock (&response->mutex);
   (void) lseek (response->fd, pos + response->fd_off, SEEK_SET);
-  ret = read (response->fd, buf, max);
-  pthread_mutex_unlock (&response->mutex);
-  return ret;
+  return read (response->fd, buf, max);
 }
 
 
@@ -352,6 +348,7 @@ struct MHD_Response *MHD_create_response_from_fd (size_t size,
  *        right away, the data maybe released anytime after
  *        this call returns
  * @return NULL on error (i.e. invalid arguments, out of memory)
+ * @deprecated use MHD_create_response_from_buffer instead
  */
 struct MHD_Response *
 MHD_create_response_from_data (size_t size,
@@ -382,7 +379,7 @@ MHD_create_response_from_data (size_t size,
           return NULL;
         }
       memcpy (tmp, data, size);
-      must_free = 1;
+      must_free = MHD_YES;
       data = tmp;
     }
   retVal->crc = NULL;
@@ -395,6 +392,28 @@ MHD_create_response_from_data (size_t size,
   return retVal;
 }
 
+
+/**
+ * Create a response object.  The response object can be extended with
+ * header information and then be used any number of times.
+ *
+ * @param size size of the data portion of the response
+ * @param buffer size bytes containing the response's data portion
+ * @param mode flags for buffer management
+ * @return NULL on error (i.e. invalid arguments, out of memory)
+ */
+struct MHD_Response *
+MHD_create_response_from_buffer (size_t size,
+				 void *buffer,
+				 enum MHD_ResponseMemoryMode mode)
+{
+  return MHD_create_response_from_data (size,
+					buffer,
+					mode == MHD_RESPMEM_MUST_FREE,
+					mode == MHD_RESPMEM_MUST_COPY);
+}
+
+
 /**
  * Destroy a response object and associated resources.  Note that
  * libmicrohttpd may keep some of the resources around if the response
