@@ -81,9 +81,9 @@ ahc_echo (void *cls,
   if ( (username == NULL) ||
        (0 != strcmp (username, "testuser")) )
     {
-      response = MHD_create_response_from_data(strlen (DENIED), 
-					       DENIED,
-					       MHD_NO, MHD_NO);  
+      response = MHD_create_response_from_buffer(strlen (DENIED), 
+						 DENIED,
+						 MHD_RESPMEM_PERSISTENT);  
       ret = MHD_queue_auth_fail_response(connection, realm,
 					 OPAQUE,
 					 response,
@@ -99,9 +99,9 @@ ahc_echo (void *cls,
   if ( (ret == MHD_INVALID_NONCE) ||
        (ret == MHD_NO) )
     {
-      response = MHD_create_response_from_data(strlen (DENIED), 
-					       DENIED,
-					       MHD_NO, MHD_NO);  
+      response = MHD_create_response_from_buffer(strlen (DENIED), 
+						 DENIED,
+						 MHD_RESPMEM_PERSISTENT);  
       if (NULL == response) 
 	return MHD_NO;
       ret = MHD_queue_auth_fail_response(connection, realm,
@@ -111,8 +111,8 @@ ahc_echo (void *cls,
       MHD_destroy_response(response);  
       return ret;
     }
-  response = MHD_create_response_from_data(strlen(PAGE), PAGE,
-					   MHD_NO, MHD_NO);
+  response = MHD_create_response_from_buffer(strlen(PAGE), PAGE,
+					     MHD_RESPMEM_PERSISTENT);
   ret = MHD_queue_response(connection, MHD_HTTP_OK, response);  
   MHD_destroy_response(response);
   return ret;
